@@ -18,9 +18,3 @@ export const searchByOptions = [
   { title: 'Datasets or Containers', value: 'datasets' },
   { title: 'Files', value: 'files' }
 ];
-
-export const authTypeOptions = [
-  { label: 'X.509 User Certificate', value: 'x509' },
-  { label: 'X.509 Proxy Certificate', value: 'x509_proxy' },
-  { label: 'Username & Password', value: 'userpass' }
-];
